@@ -59,7 +59,7 @@ def saved_query(asset_id: str, query_name: str, parameters: str):
     _write_to_std_out(result)
 
 
-@cli.command('invoke-schedule', help="Invoke a job or pipeline schedule..")
+@cli.command('invoke-schedule', help="Invoke a job or pipeline schedule.")
 @click.option('--asset_id', required=True, help="The asset's unique identifier.")
 @click.option('--job_name', required=True, help="The name of the job artifact (pipeline, notebook, or trigger).")
 @click.option('--schedule_name', required=False, help="Required unless you are invoking a trigger.")
@@ -73,6 +73,15 @@ def invoke_schedule(asset_id: str, job_name: str, schedule_name: str, variable_o
     })
 
 
+@cli.command('get-schedule-status', help="Gets the status of an invoked job")
+@click.option('--job_id', required=True, help="The job run id returned from the invoke call.")
+def get_schedule_status(job_id: str):
+    result = api_get('/public/schedule/status', {
+        'job_id': job_id
+    })
+    _write_to_std_out(result)
+
+
 @cli.command('save-file', help="Publish a python library to an asset.")
 @click.option('--asset_id', required=True, help="The asset's unique identifier.")
 @click.option('--file', required=True, type=click.Path(exists=True, file_okay=True, dir_okay=False),
